@@ -4,8 +4,11 @@ import dateutil
 import pytz
 
 from datetime import datetime, timedelta
-from modules.global_variables import MEDIA_SYNC_OFFSET_IN_SECONDS, EXPORT_PATH
-from modules.logger import log_critical_error
+from iauditor_exporter.modules.global_variables import (
+    MEDIA_SYNC_OFFSET_IN_SECONDS,
+    EXPORT_PATH,
+)
+from iauditor_exporter.modules.logger import log_critical_error
 
 
 def save_exported_media_to_file(logger, export_dir, media_file, filename, extension):
@@ -21,15 +24,17 @@ def save_exported_media_to_file(logger, export_dir, media_file, filename, extens
     if not os.path.exists(export_dir):
         logger.info("Creating directory at {0} for media files.".format(export_dir))
         os.makedirs(export_dir)
-    file_path = os.path.join(export_dir, filename + '.' + extension)
+    file_path = os.path.join(export_dir, filename + "." + extension)
     if os.path.isfile(file_path):
-        logger.info('Overwriting existing report at ' + file_path)
+        logger.info("Overwriting existing report at " + file_path)
     try:
-        with open(file_path, 'wb') as out_file:
+        with open(file_path, "wb") as out_file:
             shutil.copyfileobj(media_file.raw, out_file)
         del media_file
     except Exception as ex:
-        log_critical_error(logger, ex, 'Exception while writing' + file_path + ' to file')
+        log_critical_error(
+            logger, ex, "Exception while writing" + file_path + " to file"
+        )
 
 
 def check_if_media_sync_offset_satisfied(logger, settings, audit):
@@ -42,20 +47,24 @@ def check_if_media_sync_offset_satisfied(logger, settings, audit):
     :param audit:     Audit JSON
     :return:          Boolean - True if the media sync offset is satisfied, otherwise, returns false.
     """
-    modified_at = dateutil.parser.parse(audit['modified_at'])
+    modified_at = dateutil.parser.parse(audit["modified_at"])
     now = datetime.utcnow()
-    elapsed_time_difference = (pytz.utc.localize(now) - modified_at)
+    elapsed_time_difference = pytz.utc.localize(now) - modified_at
     # if the media_sync_offset has been satisfied
-    if not elapsed_time_difference > timedelta(seconds=settings[MEDIA_SYNC_OFFSET_IN_SECONDS]):
+    if not elapsed_time_difference > timedelta(
+        seconds=settings[MEDIA_SYNC_OFFSET_IN_SECONDS]
+    ):
         logger.info(
-            'Audit {0} modified too recently, some media may not have completed syncing. '
-            'Skipping export until next sync cycle'.format(
-                audit['audit_id']))
+            "Audit {0} modified too recently, some media may not have completed syncing. "
+            "Skipping export until next sync cycle".format(audit["audit_id"])
+        )
         return False
     return True
 
 
-def export_audit_media(logger, sc_client, settings, audit_json, audit_id, export_filename):
+def export_audit_media(
+    logger, sc_client, settings, audit_json, audit_id, export_filename
+):
     """
     Save audit media files to disk
     :param logger:      The logger
@@ -65,20 +74,22 @@ def export_audit_media(logger, sc_client, settings, audit_json, audit_id, export
     :param audit_id:    Unique audit UUID
     :param export_filename:     String indicating what to name the exported audit file
     """
-    media_export_path = os.path.join(settings[EXPORT_PATH], 'media', export_filename)
+    media_export_path = os.path.join(settings[EXPORT_PATH], "media", export_filename)
     media_id_list = get_media_from_audit(logger, audit_json)
     for media_id in media_id_list:
         extension = media_id[1]
         media_id = media_id[0]
         if not extension:
-            extension = 'jpg'
+            extension = "jpg"
         media_file = sc_client.get_media(audit_id, media_id)
         if media_file is None:
             logger.warn("Failed to save media object {0}".format(media_id))
             continue
         logger.info("Saving media_{0} to disc.".format(media_id))
         media_export_filename = media_id
-        save_exported_media_to_file(logger, media_export_path, media_file, media_export_filename, extension)
+        save_exported_media_to_file(
+            logger, media_export_path, media_file, media_export_filename, extension
+        )
 
 
 def get_media_from_audit(logger, audit_json):
@@ -89,28 +100,32 @@ def get_media_from_audit(logger, audit_json):
     :return: list of media IDs
     """
     media_id_list = []
-    for item in audit_json['header_items'] + audit_json['items']:
+    for item in audit_json["header_items"] + audit_json["items"]:
         # This condition checks for media attached to question and media type fields.
-        if 'media' in item.keys():
-            for media in item['media']:
-                if 'file_ext' in media.keys():
-                    file_ext = media['file_ext']
+        if "media" in item.keys():
+            for media in item["media"]:
+                if "file_ext" in media.keys():
+                    file_ext = media["file_ext"]
                 else:
-                    file_ext = 'jpg'
-                media_id_list.append([media['media_id'], file_ext])
+                    file_ext = "jpg"
+                media_id_list.append([media["media_id"], file_ext])
         # This condition checks for media attached to signature and drawing type fields.
-        if 'responses' in item.keys() and 'image' in item['responses'].keys():
-            if 'file_ext' in item['responses']['image'].keys():
-                file_ext = item['responses']['image']['file_ext']
+        if "responses" in item.keys() and "image" in item["responses"].keys():
+            if "file_ext" in item["responses"]["image"].keys():
+                file_ext = item["responses"]["image"]["file_ext"]
             else:
-                file_ext = 'jpg'
-            media_id_list.append([item['responses']['image']['media_id'], file_ext])
+                file_ext = "jpg"
+            media_id_list.append([item["responses"]["image"]["media_id"], file_ext])
         # This condition checks for media attached to information type fields.
-        if 'options' in item.keys() and 'media' in item['options'].keys():
-            if 'file_ext' in item['options']['media'].keys():
-                file_ext = item['options']['media']['file_ext']
+        if "options" in item.keys() and "media" in item["options"].keys():
+            if "file_ext" in item["options"]["media"].keys():
+                file_ext = item["options"]["media"]["file_ext"]
             else:
-                file_ext = 'jpg'
-            media_id_list.append([item['options']['media']['media_id'], file_ext])
-    logger.info("Discovered {0} media files associated with {1}.".format(len(media_id_list), audit_json['audit_id']))
+                file_ext = "jpg"
+            media_id_list.append([item["options"]["media"]["media_id"], file_ext])
+    logger.info(
+        "Discovered {0} media files associated with {1}.".format(
+            len(media_id_list), audit_json["audit_id"]
+        )
+    )
     return media_id_list
