@@ -1,4 +1,13 @@
-from sqlalchemy import Column, String, Integer, Float, DateTime, Boolean, BigInteger, Unicode
+from sqlalchemy import (
+    Column,
+    String,
+    Integer,
+    Float,
+    DateTime,
+    Boolean,
+    BigInteger,
+    Unicode,
+)
 
 
 def set_table(table, merge, Base):
@@ -54,56 +63,57 @@ def set_table(table, merge, Base):
         AuditArea = Column(Unicode())
         AuditRegion = Column(Unicode())
         Archived = Column(Boolean)
+
     return Database
 
 
 SQL_HEADER_ROW = [
-    'SortingIndex',
-    'ItemType',
-    'Label',
-    'Response',
-    'Comment',
-    'MediaHypertextReference',
-    'Latitude',
-    'Longitude',
-    'ItemScore',
-    'ItemMaxScore',
-    'ItemScorePercentage',
-    'Mandatory',
-    'FailedResponse',
-    'Inactive',
-    'ItemID',
-    'ResponseID',
-    'ParentID',
-    'AuditOwner',
-    'AuditAuthor',
-    'AuditOwnerID',
-    'AuditAuthorID',
-    'AuditName',
-    'AuditScore',
-    'AuditMaxScore',
-    'AuditScorePercentage',
-    'AuditDuration',
-    'DateStarted',
-    'DateCompleted',
-    'DateModified',
-    'AuditID',
-    'TemplateID',
-    'TemplateName',
-    'TemplateAuthor',
-    'TemplateAuthorID',
-    'ItemCategory',
-    'RepeatingSectionParentID',
-    'DocumentNo',
-    'ConductedOn',
-    'PreparedBy',
-    'Location',
-    'Personnel',
-    'ClientSite',
-    'AuditSite',
-    'AuditArea',
-    'AuditRegion',
-    'Archived'
+    "SortingIndex",
+    "ItemType",
+    "Label",
+    "Response",
+    "Comment",
+    "MediaHypertextReference",
+    "Latitude",
+    "Longitude",
+    "ItemScore",
+    "ItemMaxScore",
+    "ItemScorePercentage",
+    "Mandatory",
+    "FailedResponse",
+    "Inactive",
+    "ItemID",
+    "ResponseID",
+    "ParentID",
+    "AuditOwner",
+    "AuditAuthor",
+    "AuditOwnerID",
+    "AuditAuthorID",
+    "AuditName",
+    "AuditScore",
+    "AuditMaxScore",
+    "AuditScorePercentage",
+    "AuditDuration",
+    "DateStarted",
+    "DateCompleted",
+    "DateModified",
+    "AuditID",
+    "TemplateID",
+    "TemplateName",
+    "TemplateAuthor",
+    "TemplateAuthorID",
+    "ItemCategory",
+    "RepeatingSectionParentID",
+    "DocumentNo",
+    "ConductedOn",
+    "PreparedBy",
+    "Location",
+    "Personnel",
+    "ClientSite",
+    "AuditSite",
+    "AuditArea",
+    "AuditRegion",
+    "Archived",
 ]
 
 
@@ -132,25 +142,26 @@ def set_actions_table(table, merge, Base):
         createdDatetime = Column(DateTime)
         modifiedDatetime = Column(DateTime)
         completedDatetime = Column(DateTime)
+
     return ActionsDatabase
 
 
 ACTIONS_HEADER_ROW = [
-    'actionId',
-    'description',
-    'assignee',
-    'priority',
-    'priorityCode',
-    'status',
-    'statusCode',
-    'dueDatetime',
-    'audit',
-    'auditId',
-    'linkedToItem',
-    'linkedToItemId',
-    'creatorName',
-    'creatorId',
-    'createdDatetime',
-    'modifiedDatetime',
-    'completedDatetime'
-]
\ No newline at end of file
+    "actionId",
+    "description",
+    "assignee",
+    "priority",
+    "priorityCode",
+    "status",
+    "statusCode",
+    "dueDatetime",
+    "audit",
+    "auditId",
+    "linkedToItem",
+    "linkedToItemId",
+    "creatorName",
+    "creatorId",
+    "createdDatetime",
+    "modifiedDatetime",
+    "completedDatetime",
+]
